@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #
 #  __init__.py
-"""
+r"""
 Extensions to :mod:`sphinx.ext.autosummary`.
 
 Provides an enhanced version of https://autodocsumm.readthedocs.io/
@@ -23,6 +23,8 @@ and created a broken link..
 	Autosummary now selects the appropriate documenter for attributes rather than
 	falling back to :class:`~sphinx.ext.autodoc.DataDocumenter`.
 
+.. latex:vspace:: -10px
+
 
 Configuration
 --------------
@@ -40,9 +42,14 @@ The member order can also be set on a per-directive basis using the ``:member-or
 This applies not only to :rst:dir:`automodule` etc. directives,
 but also to :rst:dir:`automodulesumm` etc. directives.
 
+.. latex:vspace:: -10px
+
 
 API Reference
 ----------------
+
+.. latex:vspace:: -10px
+
 """
 #
 #  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -129,12 +136,21 @@ def add_autosummary(self):
 	sourcename = self.get_sourcename()
 	grouped_documenters = self.get_grouped_documenters()
 
+	if not self.options.get("autosummary-no-titles", False) and grouped_documenters:
+		content.blankline()
+		content.append(".. latex:vspace:: 10px")
+		content.blankline()
+
 	for section, documenters in grouped_documenters.items():
 		if not self.options.get("autosummary-no-titles", False):
 			content.append(f"**{section}:**")
+			content.blankline()
+			content.append(".. latex:vspace:: -5px")
 
 		content.blankline(ensure_single=True)
 
+		# TODO transform to make caption associated with table in LaTeX
+
 		content.append(".. autosummary::")
 		content.blankline(ensure_single=True)
 
@@ -205,6 +221,10 @@ class PatchedAutosummary(Autosummary):
 
 			Now selects the appropriate documenter for attributes rather than
 			falling back to :class:`~sphinx.ext.autodoc.DataDocumenter`.
+
+		:rtype:
+
+		.. clearpage::
 		"""
 
 		doccls = get_documenter(app, obj, parent)
